@@ -1,12 +1,17 @@
 # SPDX-FileCopyrightText: 2021 ladyada for Adafruit Industries
 # SPDX-License-Identifier: MIT
 
+# You must add a gamepad HID device inside your boot.py file
+# in order to use this example.
+# See this Learn Guide for details:
+# https://learn.adafruit.com/customizing-usb-devices-in-circuitpython/hid-devices#custom-hid-devices-3096614-9
+
 import board
 import digitalio
 import analogio
 import usb_hid
 
-from adafruit_hid.gamepad import Gamepad
+from hid_gamepad import Gamepad
 
 gp = Gamepad(usb_hid.devices)
 
